@@ -14,9 +14,7 @@ class BulkHookManager(models.Manager):
         Delegate to QuerySet's bulk_update implementation.
         This follows Django's pattern where Manager methods call QuerySet methods.
         """
-        return self.get_queryset().bulk_update(
-            objs, fields, bypass_hooks=bypass_hooks, bypass_validation=bypass_validation, **kwargs
-        )
+        return self.get_queryset().bulk_update(objs, fields, bypass_hooks, bypass_validation, **kwargs)
 
     def bulk_create(
         self,
@@ -33,15 +31,18 @@ class BulkHookManager(models.Manager):
         Delegate to QuerySet's bulk_create implementation.
         This follows Django's pattern where Manager methods call QuerySet methods.
         """
+        kwargs = {
+            'batch_size': batch_size,
+            'ignore_conflicts': ignore_conflicts,
+            'update_conflicts': update_conflicts,
+            'update_fields': update_fields,
+            'unique_fields': unique_fields,
+        }
         return self.get_queryset().bulk_create(
             objs,
-            batch_size=batch_size,
-            ignore_conflicts=ignore_conflicts,
-            update_conflicts=update_conflicts,
-            update_fields=update_fields,
-            unique_fields=unique_fields,
             bypass_hooks=bypass_hooks,
             bypass_validation=bypass_validation,
+            **kwargs
         )
 
     def bulk_delete(
@@ -51,9 +52,10 @@ class BulkHookManager(models.Manager):
         Delegate to QuerySet's bulk_delete implementation.
         This follows Django's pattern where Manager methods call QuerySet methods.
         """
-        return self.get_queryset().bulk_delete(
-            objs, batch_size=batch_size, bypass_hooks=bypass_hooks, bypass_validation=bypass_validation
-        )
+        kwargs = {
+            'batch_size': batch_size,
+        }
+        return self.get_queryset().bulk_delete(objs, bypass_hooks=bypass_hooks, bypass_validation=bypass_validation, **kwargs)
 
     def update(self, **kwargs):
         """
