@@ -120,19 +120,28 @@ class HookQuerySet(models.QuerySet):
         # For MTI models, we need to handle them specially
         if is_mti:
             # Use our MTI-specific logic
+            # Filter out custom parameters that Django's bulk_create doesn't accept
+            mti_kwargs = {
+                'batch_size': batch_size,
+                'ignore_conflicts': ignore_conflicts,
+                'update_conflicts': update_conflicts,
+                'update_fields': update_fields,
+                'unique_fields': unique_fields,
+            }
+            # Remove custom hook kwargs if present in self.bulk_create signature
             result = self._mti_bulk_create(
                 objs,
-                batch_size=batch_size,
-                ignore_conflicts=ignore_conflicts,
-                update_conflicts=update_conflicts,
-                update_fields=update_fields,
-                unique_fields=unique_fields,
+                **{k: v for k, v in mti_kwargs.items() if k not in ['bypass_hooks', 'bypass_validation']}
             )
         else:
             # For single-table models, use Django's built-in bulk_create
             # but we need to call it on the base manager to avoid recursion
+            # Filter out custom parameters that Django's bulk_create doesn't accept
 
-            result = model_cls._base_manager.bulk_create(
+            # Use Django's original QuerySet to avoid recursive calls
+            from django.db.models import QuerySet
+            original_qs = QuerySet(model_cls, using=self.db)
+            result = original_qs.bulk_create(
                 objs,
                 batch_size=batch_size,
                 ignore_conflicts=ignore_conflicts,
@@ -141,8 +150,7 @@ class HookQuerySet(models.QuerySet):
                 unique_fields=unique_fields,
             )
 
-        if not bypass_hooks:
-            engine.run(model_cls, AFTER_CREATE, objs, ctx=ctx)
+
 
         return result
 
@@ -189,7 +197,9 @@ class HookQuerySet(models.QuerySet):
             chunk = objs[i : i + self.CHUNK_SIZE]
 
             # Call the base implementation to avoid re-triggering this method
-            super().bulk_update(chunk, fields, **kwargs)
+            # Filter out custom parameters that Django's bulk_update doesn't accept
+            django_kwargs = {k: v for k, v in kwargs.items() if k not in ['bypass_hooks', 'bypass_validation']}
+            super().bulk_update(chunk, fields, **django_kwargs)
 
         if not bypass_hooks:
             engine.run(model_cls, AFTER_UPDATE, objs, originals, ctx=ctx)
@@ -294,6 +304,8 @@ class HookQuerySet(models.QuerySet):
         then single bulk insert into childmost table.
         Sets auto_now_add/auto_now fields for each model in the chain.
         """
+        # Remove custom hook kwargs before passing to Django internals
+        django_kwargs = {k: v for k, v in kwargs.items() if k not in ['bypass_hooks', 'bypass_validation']}
         if inheritance_chain is None:
             inheritance_chain = self._get_inheritance_chain()
 
@@ -303,13 +315,13 @@ class HookQuerySet(models.QuerySet):
                 "Inheritance chain too deep - possible infinite recursion detected"
             )
 
-        batch_size = kwargs.get("batch_size") or len(objs)
+        batch_size = django_kwargs.get("batch_size") or len(objs)
         created_objects = []
         with transaction.atomic(using=self.db, savepoint=False):
             for i in range(0, len(objs), batch_size):
                 batch = objs[i : i + batch_size]
                 batch_result = self._process_mti_batch(
-                    batch, inheritance_chain, **kwargs
+                    batch, inheritance_chain, **django_kwargs
                 )
                 created_objects.extend(batch_result)
         return created_objects
@@ -325,6 +337,10 @@ class HookQuerySet(models.QuerySet):
         parent_objects_map = {}
 
         # Step 1: Do O(n) normal inserts into parent tables to get primary keys back
+        # Get bypass_hooks from kwargs
+        bypass_hooks = kwargs.get('bypass_hooks', False)
+        bypass_validation = kwargs.get('bypass_validation', False)
+        
         for obj in batch:
             parent_instances = {}
             current_parent = None
@@ -332,6 +348,14 @@ class HookQuerySet(models.QuerySet):
                 parent_obj = self._create_parent_instance(
                     obj, model_class, current_parent
                 )
+                
+                # Fire parent hooks if not bypassed
+                if not bypass_hooks:
+                    ctx = HookContext(model_class)
+                    if not bypass_validation:
+                        engine.run(model_class, VALIDATE_CREATE, [parent_obj], ctx=ctx)
+                    engine.run(model_class, BEFORE_CREATE, [parent_obj], ctx=ctx)
+                
                 # Use Django's base manager to create the object and get PKs back
                 # This bypasses hooks and the MTI exception
                 field_values = {
@@ -340,10 +364,16 @@ class HookQuerySet(models.QuerySet):
                     if hasattr(parent_obj, field.name) and getattr(parent_obj, field.name) is not None
                 }
                 created_obj = model_class._base_manager.using(self.db).create(**field_values)
+                
                 # Update the parent_obj with the created object's PK
                 parent_obj.pk = created_obj.pk
                 parent_obj._state.adding = False
                 parent_obj._state.db = self.db
+                
+                # Fire AFTER_CREATE hooks for parent
+                if not bypass_hooks:
+                    engine.run(model_class, AFTER_CREATE, [parent_obj], ctx=ctx)
+                
                 parent_instances[model_class] = parent_obj
                 current_parent = parent_obj
             parent_objects_map[id(obj)] = parent_instances
@@ -357,15 +387,65 @@ class HookQuerySet(models.QuerySet):
             )
             all_child_objects.append(child_obj)
 
-        # Step 2.5: Single bulk insert into childmost table
+        # Step 2.5: Use Django's internal bulk_create infrastructure
         if all_child_objects:
-            # Use Django's internal bulk_create to bypass MTI exception
-            child_model._base_manager.bulk_create(all_child_objects)
+            # Get the base manager's queryset
+            base_qs = child_model._base_manager.using(self.db)
+            
+            # Use Django's exact approach: call _prepare_for_bulk_create then partition
+            base_qs._prepare_for_bulk_create(all_child_objects)
+            
+            # Implement our own partition since itertools.partition might not be available
+            objs_without_pk, objs_with_pk = [], []
+            for obj in all_child_objects:
+                if obj._is_pk_set():
+                    objs_with_pk.append(obj)
+                else:
+                    objs_without_pk.append(obj)
+            
+            # Use Django's internal _batched_insert method
+            opts = child_model._meta
+            # For child models in MTI, we need to include the foreign key to the parent
+            # but exclude the primary key since it's inherited
+            
+            # Include all local fields except generated ones
+            # We need to include the foreign key to the parent (business_ptr)
+            fields = [f for f in opts.local_fields if not f.generated]
+            
+            with transaction.atomic(using=self.db, savepoint=False):
+                 if objs_with_pk:
+                     returned_columns = base_qs._batched_insert(
+                         objs_with_pk,
+                         fields,
+                         batch_size=len(objs_with_pk),  # Use actual batch size
+                     )
+                     for obj_with_pk, results in zip(objs_with_pk, returned_columns):
+                         for result, field in zip(results, opts.db_returning_fields):
+                             if field != opts.pk:
+                                 setattr(obj_with_pk, field.attname, result)
+                     for obj_with_pk in objs_with_pk:
+                         obj_with_pk._state.adding = False
+                         obj_with_pk._state.db = self.db
+                 
+                 if objs_without_pk:
+                     # For objects without PK, we still need to exclude primary key fields
+                     fields = [f for f in fields if not isinstance(f, AutoField) and not f.primary_key]
+                     returned_columns = base_qs._batched_insert(
+                         objs_without_pk,
+                         fields,
+                         batch_size=len(objs_without_pk),  # Use actual batch size
+                     )
+                     for obj_without_pk, results in zip(objs_without_pk, returned_columns):
+                         for result, field in zip(results, opts.db_returning_fields):
+                             setattr(obj_without_pk, field.attname, result)
+                         obj_without_pk._state.adding = False
+                         obj_without_pk._state.db = self.db
 
         # Step 3: Update original objects with generated PKs and state
         pk_field_name = child_model._meta.pk.name
         for orig_obj, child_obj in zip(batch, all_child_objects):
-            setattr(orig_obj, pk_field_name, getattr(child_obj, pk_field_name))
+            child_pk = getattr(child_obj, pk_field_name)
+            setattr(orig_obj, pk_field_name, child_pk)
             orig_obj._state.adding = False
             orig_obj._state.db = self.db
 
@@ -404,6 +484,7 @@ class HookQuerySet(models.QuerySet):
 
     def _create_child_instance(self, source_obj, child_model, parent_instances):
         child_obj = child_model()
+        # Only copy fields that exist in the child model's local fields
         for field in child_model._meta.local_fields:
             if isinstance(field, AutoField):
                 continue
@@ -411,10 +492,15 @@ class HookQuerySet(models.QuerySet):
                 value = getattr(source_obj, field.name, None)
                 if value is not None:
                     setattr(child_obj, field.name, value)
+        
+        # Set parent links for MTI
         for parent_model, parent_instance in parent_instances.items():
             parent_link = child_model._meta.get_ancestor_link(parent_model)
             if parent_link:
-                setattr(child_obj, parent_link.name, parent_instance)
+                # Set both the foreign key value (the ID) and the object reference
+                # This follows Django's pattern in _set_pk_val
+                setattr(child_obj, parent_link.attname, parent_instance.pk)  # Set the foreign key value
+                setattr(child_obj, parent_link.name, parent_instance)        # Set the object reference
 
         # Handle auto_now_add and auto_now fields like Django does
         for field in child_model._meta.local_fields:
